PlumpIconData class

Annotations

Constructors

PlumpIconData(String assetName, {required String style, required String name})
const

Properties

assetName String
Asset path inside the package.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Normalized icon name, for example: home-1, search-visual.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style String
Icon style, for example: line, solid.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited